#![allow(clippy::redundant_static_lifetimes)]

#[rustfmt::skip]
mod unprintable;
pub(super) use unprintable::UNPRINTABLE;
